# How to cite

@misc{Ceglia2022biosiglive,
author = {Ceglia, Amedeo, Felipe, Verdugo and Begon, Mickael},
title = {`Biosiglive`: an Open Sources python package for real-time biosignals processing.},
howpublished={Web page},
url = {https://github.com/pyomeca/biosiglive},
year = {2022}
}

